#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MFOUR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MFOUR_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mfour.hpp>

#endif
